@@ -28,6 +28,7 @@ from subunit import (
 from testresources import TestResource
 from testtools import (
     clone_test_with_new_id,
+    content,
     PlaceHolder,
     )
 import testtools
@@ -103,19 +104,25 @@ class Case(ResourcedTestCase):
     def passing(self):
         pass
 
-    def failing(self):
-        self.fail("oops")
-
     def unexpected_success(self):
         self.expectFailure("unexpected success", self.assertTrue, True)
 
 
+class FailingCase:
+
+    def run(self, result):
+        result.startTest(self)
+        result.addError(
+            self, None, details={'traceback': content.text_content("tb")})
+        result.stopTest(self)
+
+
 def make_test(id, should_pass):
     """Make a test."""
     if should_pass:
         case = Case("passing")
     else:
-        case = Case("failing")
+        case = FailingCase()
     return clone_test_with_new_id(case, id)
 
 
@@ -403,7 +410,7 @@ class TestRepositoryContract(ResourcedTestCase):
         finally:
             log.stopTestRun()
         self.assertEqual(
-            log._events, [
+            [tuple(ev) for ev in log._events], [
             ('startTestRun',),
             ('status',
              'testrepository.tests.test_repository.Case.method',
@@ -459,7 +466,7 @@ class TestRepositoryContract(ResourcedTestCase):
         finally:
             log.stopTestRun()
         self.assertEqual(
-            log._events,
+            [tuple(ev) for ev in log._events],
             [
             ('startTestRun',),
             ('status',
